from setuptools import setup

setup(name='ie_mbdbl2017_A_yahoo_ks_datareader',
      version='0.1',  # Development release
      description='Python Packaging Starting Kit - Simple Structure to creater your own package - for training purposes!',
      url='https://github.com/michela23/ie_mbdbl2017_A_yahoo_ks_datareader',
      author='Group A IE GMBD 2017',
      author_email='michel.aa@faculty.ie.edu',
      license='MIT',
          packages=['ie_mbdbl2017_A_yahoo_ks_datareader'],
      zip_safe=False)